@@ -26,6 +26,7 @@ import numpy as np
 
 from pymatgen.core.periodic_table import Element, Specie
 from pymatgen.util.io_utils import zopen
+from pymatgen.util.coord_utils import in_coord_list_pbc
 from pymatgen.core.lattice import Lattice
 from pymatgen.core.structure import Structure
 from pymatgen.core.composition import Composition
@@ -56,6 +57,19 @@ class CifParser(object):
 
     @staticmethod
     def from_string(cif_string, occupancy_tolerance=1.):
+        """
+        Creates a CifParser from a string.
+
+        Args:
+            cif_string:
+                String representation of a CIF.
+            occupancy_tolerance:
+                If total occupancy of a site is between 1 and
+                occupancy_tolerance, the occupancies will be scaled down to 1.
+
+        Returns:
+            CifParser
+        """
         output = StringIO.StringIO()
         output.write(cif_string)
         output.seek(0)
@@ -65,14 +79,14 @@ class CifParser(object):
         """
         Generate unique coordinates using coord and symmetry positions.
         """
-        coords = list()
+        coords = []
         for op in self.symmetry_operations:
             coord = op.operate(coord_in)
             if primitive:
                 cart = lattice.get_cartesian_coords(np.array(coord))
                 coord = primlattice.get_fractional_coords(cart)
             coord = np.array([i - math.floor(i) for i in coord])
-            if not coord_in_list(coord, coords, 1e-3):
+            if not in_coord_list_pbc(coords, coord, atol=1e-3):
                 coords.append(coord)
         return coords
 
@@ -94,13 +108,13 @@ class CifParser(object):
         primlattice = lattice.get_primitive_lattice(latt_type)
         try:
             sympos = data["_symmetry_equiv_pos_as_xyz"]
-        except:
+        except KeyError:
             try:
                 sympos = data["_symmetry_equiv_pos_as_xyz_"]
-            except:
+            except KeyError:
                 warnings.warn("No _symmetry_equiv_pos_as_xyz type key found. "
                               "Defaulting to P1.")
-                sympos
+                sympos = ['x, y, z']
         self.symmetry_operations = parse_symmetry_operations(sympos)
 
         def parse_symbol(sym):
@@ -111,11 +125,10 @@ class CifParser(object):
 
         #oxi_states = None
         try:
-            oxi_states = dict()
-            for i in xrange(len(data["_atom_type_symbol"])):
-                oxi_states[data["_atom_type_symbol"][i]] = \
-                    float_from_str(data["_atom_type_oxidation_number"][i])
-        except:
+            oxi_states = {data["_atom_type_symbol"][i]:
+                          float_from_str(data["_atom_type_oxidation_number"][i])
+                          for i in xrange(len(data["_atom_type_symbol"]))}
+        except (ValueError, KeyError):
             oxi_states = None
 
         coord_to_species = OrderedDict()
@@ -132,7 +145,7 @@ class CifParser(object):
             z = float_from_str(data["_atom_site_fract_z"][i])
             try:
                 occu = float_from_str(data["_atom_site_occupancy"][i])
-            except:
+            except ValueError:
                 occu = 1
             if occu > 0:
                 coord = (x, y, z)
@@ -141,8 +154,8 @@ class CifParser(object):
                 else:
                     coord_to_species[coord][el] = occu
 
-        allspecies = list()
-        allcoords = list()
+        allspecies = []
+        allcoords = []
 
         for coord, species in coord_to_species.items():
             coords = self._unique_coords(coord, primitive, lattice,
@@ -203,14 +216,12 @@ class CifWriter:
         block = CifFile.CifBlock()
         latt = struct.lattice
         comp = struct.composition
-        no_oxi_comp = Composition.from_formula(comp.formula)
+        no_oxi_comp = Composition(comp.formula)
         block["_symmetry_space_group_name_H-M"] = "P 1"
-        block["_cell_length_a"] = str(latt.a)
-        block["_cell_length_b"] = str(latt.b)
-        block["_cell_length_c"] = str(latt.c)
-        block["_cell_angle_alpha"] = str(latt.alpha)
-        block["_cell_angle_beta"] = str(latt.beta)
-        block["_cell_angle_gamma"] = str(latt.gamma)
+        for cell_attr in ['a', 'b', 'c']:
+            block["_cell_length_" + cell_attr] = str(getattr(latt, cell_attr))
+        for cell_attr in ['alpha', 'beta', 'gamma']:
+            block["_cell_angle_" + cell_attr] = str(getattr(latt, cell_attr))
         block["_chemical_name_systematic"] = "Generated by pymatgen"
         block["_symmetry_Int_Tables_number"] = 1
         block["_chemical_formula_structural"] = str(no_oxi_comp
@@ -229,10 +240,9 @@ class CifWriter:
                           [[["1"], ["x, y, z"]]]))
 
         contains_oxidation = True
-        symbol_to_oxinum = dict()
         try:
             symbol_to_oxinum = {str(el): el.oxi_state for el in comp.elements}
-        except:
+        except AttributeError:
             symbol_to_oxinum = {el.symbol: 0 for el in comp.elements}
             contains_oxidation = False
         if contains_oxidation:
@@ -255,12 +265,12 @@ class CifWriter:
             for sp, occu in site.species_and_occu.items():
                 atom_site_type_symbol.append(str(sp))
                 atom_site_symmetry_multiplicity.append("1")
-                atom_site_fract_x.append(str("{0:f}".format(site.a)))
-                atom_site_fract_y.append(str("{0:f}".format(site.b)))
-                atom_site_fract_z.append(str("{0:f}".format(site.c)))
+                atom_site_fract_x.append("{0:f}".format(site.a))
+                atom_site_fract_y.append("{0:f}".format(site.b))
+                atom_site_fract_z.append("{0:f}".format(site.c))
                 atom_site_attached_hydrogens.append("0")
                 atom_site_B_iso_or_equiv.append(".")
-                atom_site_label.append(str(sp.symbol) + str(count))
+                atom_site_label.append("{}{}".format(sp.symbol, count))
                 atom_site_occupancy.append(str(occu))
                 count += 1
 
@@ -304,27 +314,6 @@ class CifWriter:
             f.write(self.__str__())
 
 
-def around_diff_num(a, b):
-    """
-    Used to compare differences in fractional coordinates, taking into account
-    PBC.
-    """
-    diff_num = abs(a - b)
-    return diff_num if diff_num < 0.5 else abs(1 - diff_num)
-
-
-def coord_in_list(coord, coord_list, tol):
-    """
-    Helper method to check if coord is already in a list of coords, subject to
-    a tolerance.
-    """
-    for c in coord_list:
-        diff = np.array([around_diff_num(c[i], coord[i]) for i in xrange(3)])
-        if (diff < tol).all():
-            return True
-    return False
-
-
 def float_from_str(text):
     """
     Remove uncertainty brackets from strings and return the float.
@@ -332,14 +321,25 @@ def float_from_str(text):
     return float(re.sub("\(.+\)", "", text))
 
 
-def parse_symmetry_operations(symmops_str):
+def parse_symmetry_operations(symmops_str_list):
+    """
+    Help method to parse the symmetry operations.
+
+    Args:
+        symmops_str_list:
+            List of symmops strings of the form
+            ['x, y, z', '-x, -y, z', '-y+1/2, x+1/2, z+1/2', ...]
+
+    Returns:
+        List of SymmOps
+    """
     ops = []
-    for op_str in symmops_str:
+    for op_str in symmops_str_list:
         rot_matrix = np.zeros((3, 3))
         trans = np.zeros(3)
         toks = op_str.strip().split(",")
         for i, tok in enumerate(toks):
-            for m in re.finditer("([\+\-]*)\s*([x-z\d]+)\/*(\d*)", tok):
+            for m in re.finditer("([\+\-]*)\s*([x-z\d]+)/*(\d*)", tok):
                 factor = -1 if m.group(1) == "-" else 1
                 if m.group(2) in ("x", "y", "z"):
                     j = ord(m.group(2)) - 120
@@ -347,7 +347,7 @@ def parse_symmetry_operations(symmops_str):
                 else:
                     num = float(m.group(2))
                     if m.group(3) != "":
-                        num = num / float(m.group(3))
+                        num /= float(m.group(3))
                     trans[i] = factor * num
         op = SymmOp.from_rotation_and_translation(rot_matrix, trans)
         ops.append(op)
