@@ -14,22 +14,8 @@ import itertools
 import json
 import math
 import os
-import pymatgen
 
 
-def test_table():
-    """
-    Loads a lightweight lambda table for use in unit tests to reduce
-    initialization time, and make unit tests insensitive to changes in the
-    default lambda table.
-    """
-    module_dir = os.path.dirname(pymatgen.__file__)
-    json_file = os.path.join(module_dir, 'structure_prediction', 'tests',
-                             'test_data', 'test_lambda.json')
-    with open(json_file) as f:
-        lambda_table = json.load(f)
-    return lambda_table
-
 @cached_class
 class SubstitutionProbability(object):
     """
@@ -49,9 +35,8 @@ class SubstitutionProbability(object):
         self._lambda_table = lambda_table
 
         if not lambda_table:
-            module_dir = os.path.dirname(pymatgen.__file__)
-            json_file = os.path.join(module_dir, 'structure_prediction',
-                                     'data', 'lambda.json')
+            module_dir = os.path.dirname(__file__)
+            json_file = os.path.join(module_dir, 'data', 'lambda.json')
             with open(json_file) as f:
                 lambda_table = json.load(f)
 
